NetEvent

Enum NetEvent 

pub enum NetEvent {
Show 13 variants ExecutionStarted { net_name: Arc<str>, timestamp: u64, }, ExecutionCompleted { net_name: Arc<str>, timestamp: u64, }, TransitionEnabled { transition_name: Arc<str>, timestamp: u64, }, TransitionClockRestarted { transition_name: Arc<str>, timestamp: u64, }, TransitionStarted { transition_name: Arc<str>, timestamp: u64, }, TransitionCompleted { transition_name: Arc<str>, timestamp: u64, }, TransitionFailed { transition_name: Arc<str>, error: String, timestamp: u64, }, TransitionTimedOut { transition_name: Arc<str>, timestamp: u64, }, ActionTimedOut { transition_name: Arc<str>, timeout_ms: u64, timestamp: u64, }, TokenAdded { place_name: Arc<str>, timestamp: u64, }, TokenRemoved { place_name: Arc<str>, timestamp: u64, }, LogMessage { transition_name: Arc<str>, level: String, message: String, timestamp: u64, }, MarkingSnapshot { marking: HashMap<Arc<str>, usize>, timestamp: u64, },
}
All observable events during Petri net execution.

13 event types as a discriminated union matching the TypeScript/Java implementations.

Variants



ExecutionStarted

Net execution started.

Fields

net_name: Arc<str>
timestamp: u64


ExecutionCompleted

Net execution completed (no more enabled transitions, no in-flight actions).

Fields

net_name: Arc<str>
timestamp: u64


TransitionEnabled

Transition became enabled (all input/inhibitor/read conditions satisfied).

Fields

transition_name: Arc<str>
timestamp: u64


TransitionClockRestarted

Transition’s enabling clock restarted (input place tokens changed while enabled).

Fields

transition_name: Arc<str>
timestamp: u64


TransitionStarted

Transition started firing (tokens consumed, action dispatched).

Fields

transition_name: Arc<str>
timestamp: u64


TransitionCompleted

Transition completed successfully (outputs produced).

Fields

transition_name: Arc<str>
timestamp: u64


TransitionFailed

Transition action failed with error.

Fields

transition_name: Arc<str>
error: String
timestamp: u64


TransitionTimedOut

Transition exceeded its timing deadline and was force-disabled.

Fields

transition_name: Arc<str>
timestamp: u64


ActionTimedOut

Transition action exceeded its action timeout.

Fields

transition_name: Arc<str>
timeout_ms: u64
timestamp: u64


TokenAdded

Token added to a place.

Fields

place_name: Arc<str>
timestamp: u64


TokenRemoved

Token removed from a place.

Fields

place_name: Arc<str>
timestamp: u64


LogMessage

Log message emitted by a transition action.

Fields

transition_name: Arc<str>
level: String
message: String
timestamp: u64


MarkingSnapshot

Snapshot of the current marking (token counts per place).

Fields

marking: HashMap<Arc<str>, usize>
timestamp: u64

Implementations

Source

impl NetEvent

pub fn timestamp(&self) -> u64

Returns the timestamp of this event.

pub fn transition_name(&self) -> Option<&str>

Returns the transition name if this event is transition-related.

pub fn is_failure(&self) -> bool

Returns true if this is a failure event.